summaryrefslogtreecommitdiff
path: root/fml/lib
diff options
context:
space:
mode:
authorfukachan <fukachan>2003-03-05 16:23:14 +0000
committerfukachan <fukachan>2003-03-05 16:23:14 +0000
commit3a0484264907d82ef5f0bbec9942f7c5c51d54bf (patch)
treef902b27ebc9103750792722e97e903e26cf2aca9 /fml/lib
parente3a184ac3b8734db380fdf04fd0759b5202a0a55 (diff)
downloadfml8-3a0484264907d82ef5f0bbec9942f7c5c51d54bf.tar.gz
fml8-3a0484264907d82ef5f0bbec9942f7c5c51d54bf.tar.bz2
fml8-3a0484264907d82ef5f0bbec9942f7c5c51d54bf.zip
implement rewrite_errors_to()
Diffstat (limited to 'fml/lib')
-rw-r--r--fml/lib/FML/Header.pm26
1 files changed, 23 insertions, 3 deletions
diff --git a/fml/lib/FML/Header.pm b/fml/lib/FML/Header.pm
index 224a405c..8f1d93e2 100644
--- a/fml/lib/FML/Header.pm
+++ b/fml/lib/FML/Header.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: Header.pm,v 1.52 2003/01/25 11:44:04 fukachan Exp $
+# $FML: Header.pm,v 1.53 2003/03/05 16:10:27 fukachan Exp $
#
package FML::Header;
@@ -373,7 +373,14 @@ The actual function definitions exist in C<FML::Header::Subject>.
=head2 C<rewrite_reply_to>
-add or replace C<Reply-To:>.
+replace C<Reply-To:> with this ML's address for post.
+add reply-to: if not specified.
+
+
+=head2 C<rewrite_errors_to>
+
+replace C<Errors-To:> with this ML's address for post.
+add errors-to: if not specified.
=head2 C<rewrite_date>
@@ -402,7 +409,8 @@ sub rewrite_article_subject_tag
}
# Descriptions: rewrite Reply-To: if needed
# Arguments: OBJ($header) OBJ($config) HASH_REF($args)
# Side Effects: update $header
# Return Value: none
@@ -417,6 +425,18 @@ sub rewrite_reply_to
}
+# Descriptions: rewrite Errors-To: to the maintainer.
+# add Errors-To: if not specified.
+# Arguments: OBJ($header) OBJ($config) HASH_REF($args)
+# Side Effects: update $header
+# Return Value: none
+sub rewrite_errors_to
+{
+ my ($header, $config, $args) = @_;
+ $header->add('Errors-To', $config->{ maintainer });
+}
+
+
# Descriptions: rewrite Date: to X-Date: if needed
# Arguments: OBJ($header) OBJ($config) HASH_REF($args)
# Side Effects: update $header
@@ -402,7 +409,8 @@ sub rewrite_article_subject_tag
}
-# Descriptions: rewrite Reply-To: if needed
+# Descriptions: rewrite Reply-To: to this ML's address.
+# add Reply-To: if not specified.
# Arguments: OBJ($header) OBJ($config) HASH_REF($args)
# Side Effects: update $header